import calendar

import os


from django.contrib import messages
from django.contrib.auth.models import User
from django.db.models import Count
from django.shortcuts import render, redirect
import json
from django.http import HttpResponse, HttpResponseRedirect, HttpRequest, Http404

# Create your views here.
from django.views.decorators.csrf import csrf_exempt

from catalog.models import Purchase, Search
from catalog.views import config

USERS_PATH = config['PATHS']['PATH_NAS']
PATH_USERS = config['PATHS']['PATH_USERS']
size_sentinel =0
size_repsat=0


#------------------------------------------------------------
def Dashboard(request):
    if not request.user.is_superuser and not request.user.is_staff:
        return redirect('../')

    # Total de compras #
    total = Purchase.objects.filter(purchased=True).count()

    # Usuarios activos #
    usuarios = User.objects.filter(is_active=True).count()

    # Solicitudes de Alta #
    Request = User.objects.filter(is_active=False).count()

    # Compras en progreso #
    in_process = Purchase.objects.filter(purchased=True).exclude(progress=100).count()

    # lista de meses #
    month_lst = [
        {'quantity': 0, 'date': 'January'},
        {'quantity': 0, 'date': 'February'},
        {'quantity': 0, 'date': 'March'},
        {'quantity': 0, 'date': 'April'},
        {'quantity': 0, 'date': 'May'},
        {'quantity': 0, 'date': 'June'},
        {'quantity': 0, 'date': 'July'},
        {'quantity': 0, 'date': 'August'},
        {'quantity': 0, 'date': 'September'},
        {'quantity': 0, 'date': 'October'},
        {'quantity': 0, 'date': 'November'},
        {'quantity': 0, 'date': 'December'}]

    # Obtener el nombre del mes #
    for date in Purchase.objects.filter(purchased=True).extra({'month': "Extract(month from aggreg_date)"}).values_list(
            'month').annotate(Count('id')):
        date_name = calendar.month_name[int(date[0])]

        for month in month_lst:
            if month['date'] == date_name:
                month['quantity'] = date[1]

    # Obtener las 5 busquedas m'as comunes #
    search_names = ['']
    Searches = Search.objects.values('search_name').exclude(search_name__in=search_names).annotate(
        count=Count('search_name')).order_by('-count')[:5]

    # Espacio Usado en Sentinel #

    bytes_size = 0
    for path, directories, files in os.walk(USERS_PATH + "sentinelImages"):
        for filename in files:
            bytes_size += os.lstat(os.path.join(path, filename)).st_size
        for directory in directories:
            bytes_size += os.lstat(os.path.join(path, directory)).st_size
    bytes_size += os.path.getsize(USERS_PATH + "sentinelImages")

    size_sentinel = best_unit_size(bytes_size)

    # Espacio Usado en Repsat #

    bytes_size = 0
    for path, directories, files in os.walk(USERS_PATH + "repsat_test_dev"):
        for filename in files:
            bytes_size += os.lstat(os.path.join(path, filename)).st_size
        for directory in directories:
            bytes_size += os.lstat(os.path.join(path, directory)).st_size
    bytes_size += os.path.getsize(USERS_PATH + "repsat_test_dev")
    size_repsat = best_unit_size(bytes_size)




    return render(request, 'dashboard.html',
                  {"Viewname": "Dashboard", "Usuarios": usuarios, "Total_compras": total, "Solicitud": Request,
                   "Descargando": in_process, "dates": month_lst, "search": Searches, "size_repsat": size_repsat,
                   "size_sentinel": size_sentinel})

# ----------------------------------------------------------
def Request_users(request):
    if not request.user.is_superuser and not request.user.is_staff:
        return redirect('../')
    user_list = []
    for user in User.objects.filter(is_active=False):
        user_list.append({
            "user_id": user.id,
            "username": user.username,
            "first_name": user.first_name,
            "last_name": user.last_name,
            "email": user.email,
            "status": user.is_active,
            "staff": user.is_staff,
            "superuser": user.is_superuser,
        })
    # messages.success(request, 'your registration is being processed')
    return render(request, 'users_table.html', {'users': user_list, "Viewname": "Request"})



# ------------------------------------------------------------------------
def update_user(request):

    is_active = False
    is_staff = False
    is_superuser = False

    if request.POST.get('is_active') == '1':
        is_active = True
    if request.POST.get('is_staff') == '1':
        is_staff = True
    if request.POST.get('is_superuser') == '1':
        is_superuser = True

    user = User.objects.get(pk=request.POST.get('user_id'))
    user.is_active = is_active
    user.is_staff = is_staff
    user.is_superuser = is_superuser
    user.save()

    messages.success(request, 'the user was updated')

    return redirect(request.POST.get('request_path'))

#------------------------------------------------------------------------
def active_users(request):
    if not request.user.is_superuser and not request.user.is_staff:
        return redirect('../')
    user_list = []
    for user in User.objects.filter(is_active=True):
        user_list.append({
            "user_id": user.id,
            "username": user.username,
            "first_name": user.first_name,
            "last_name": user.last_name,
            "email": user.email,
            "status": user.is_active,
            "staff": user.is_staff,
            "superuser": user.is_superuser,
        })
    # messages.success(request, 'your registration is being processed')
    return render(request, 'users_table.html', {'users': user_list, "Viewname": "Active Users"})


# ----------------------------------------------------------------------
@csrf_exempt
def wsPurchasesPM(request):
    if request.is_ajax():

        table_data =[]
        data = Purchase.objects.values('user__username','aggreg_date__month','user_id','user__email').filter(purchased=True,
            aggreg_date__month=to_if(request.POST.get('title'))).annotate(dcount=Count('user__username')).order_by('-dcount')


        for user in data:
            bytes_size = 0
            for path, directories, files in os.walk(PATH_USERS+user['user__email']):
                for filename in files:
                    bytes_size += os.lstat(os.path.join(path, filename)).st_size
                for directory in directories:
                    bytes_size += os.lstat(os.path.join(path, directory)).st_size
            bytes_size += os.path.getsize(PATH_USERS+user['user__email'])
            storage = best_unit_size(bytes_size)


            pending = Purchase.objects.filter(user_id=user['user_id'],aggreg_date__month=to_if(request.POST.get('title'))).exclude(progress=100).annotate(dcount=Count('progress'))

            table_data.append({
                'user_id':user['user_id'],
                'username':user['user__username'],
                'email':user['user__email'],
                'purchases':user['dcount'],
                'storage':storage,
                'in_process': pending.count(),
            })
        return HttpResponse(json.dumps(table_data))
    else:
        raise Http404

# ----------------------------------------------------------------------
def to_if(name):
    if name == "January":
        return 1
    elif name == "February":
        return 2
    elif name == "March":
        return 3
    elif name == "April":
        return 4
    elif name == "May":
        return 5
    elif name == "June":
        return 6
    elif name == "July":
        return 7
    elif name == "August":
        return 8
    elif name == "September":
        return 9
    elif name == "October":
        return 10
    elif name == "November":
        return 11
    elif name == "December":
        return 12
    else:
        raise ValueError

#-----------------------------------------------
def best_unit_size(bytes_size):
    """
    Obtenga un tamano en bytes y conviertalo en el mejor prefijo IEC para facilitar la lectura.

    Devuelva un diccionario con tres pares de claves / valores:

    "s" - (flotador) Tamano del camino convertido a la mejor unidad para una facil lectura
    "u" - (str) El prefijo (IEC) para s (de bytes (2 ^ 0) a YiB (2 ^ 80))
    "b" - (int / long) El tamano original en bytes

    """
    for exp in range(0, 90 , 10):
        bu_size = abs(bytes_size) / pow(2.0, exp)
        if int(bu_size) < 2 ** 10:
            unit = {0:"bytes", 10:"KB", 20:"MB", 30:"GB", 40:"TB", 50:"PB",
                    60:"EB", 70:"ZB", 80:"YB"}[exp]
            break
    return str(round(bu_size,2))+" "+unit

#------------------------------------------------
  
