# -*- coding: utf-8 -*-

"""
    Script that saves in DB the downloaded zip products.

    Usage:
    $ cd GeoInt_SIDT
    $ python manage.py populate_products_l1c
"""


from django.core.management.base import BaseCommand, CommandError
from sentinelsat.sentinel import SentinelAPI
from catalog.models import Product_l1c
import xml.etree.ElementTree as ET
import os, sys, requests, json, paramiko


usr = "emmhp"
pwd = "geoemm29"
URL_Sentinel = 'https://scihub.copernicus.eu/dhus'

apiSentinel = SentinelAPI(usr, pwd, URL_Sentinel)

SSH_ADDRESS  = "192.168.1.59"
SSH_USERNAME = "geoint"
SSH_COMMAND  = "cd NAS/sentinelImages/L1C/; pwd"

ssh = paramiko.SSHClient()
ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())


class Command(BaseCommand):
    help = "Populates DB with downloaded L1C products."

    def generate_json(self, product_name):
        """
        https://scihub.copernicus.eu/dhus/odata/v1/Products?$filter=Name eq 'S2A_MSIL1C_20161206T162652_N0204_R040_T15QZD_20161206T163422'
        """
        uri       = "https://scihub.copernicus.eu/dhus/odata/v1/Products?$filter=Name eq '" + product_name + "'"
        r         = requests.get(uri, auth=(usr, pwd))
        root      = ET.fromstring(r.content)
        # print root
        # base_link = root[5][0].text
        try:
            uuid      = root[5][11][0].text
        except:
            pass

        data_dict = apiSentinel.get_product_odata(uuid, full=True)

        return data_dict


    def handle(self, *args, **options):
        ssh_stdin = ssh_stdout = ssh_stderr = None

        try:
            ssh.connect(SSH_ADDRESS, username=SSH_USERNAME)
            ssh_stdin, ssh_stdout, ssh_stderr = ssh.exec_command(SSH_COMMAND)
            path = ssh_stdout.read().replace("\n", '')
            
            sftp = ssh.open_sftp()  ## Creates SFTPClient() object
            sftp.chdir(path)
            file_list = sftp.listdir()
            file_list.sort()

            for file in file_list:
                file_name      = file.replace(".zip", '')
                PRODUCT_EXISTS = Product_l1c.objects.filter(identifier=file_name).exists()

                if not PRODUCT_EXISTS:
                    file_path = path + "/" + file

                    try: 
                        data_dict = self.generate_json(file_name)
                        # print json.dumps(data_dict, indent=3, sort_keys=True, default=str)

                        product_l1c = Product_l1c(
                            uuid       = data_dict['id'],
                            identifier = data_dict['Identifier'],
                            file_path  = file_path,
                            json       = json.dumps(data_dict, indent=3, sort_keys=True, ensure_ascii=True, default=str)
                        )

                        product_l1c.save()
                        print "NEW product with UUID: " + data_dict['id']
                    
                    except:
                        print "ERROR with file " + file
                
                # else:
                #     print "Product " + file_name + " is ALREADY in DB."
        
        except Exception as e:
            sys.stderr.write("SSH connection error: {0}".format(e))

        if ssh_stdout:
            sys.stdout.write(ssh_stdout.read())
        if ssh_stderr:
            sys.stderr.write(ssh_stderr.read())

        sftp.close()
        ssh.close()
