# -*- coding: utf-8 -*-

## Create your models here.

from __future__ import unicode_literals
from django.contrib.auth.models import User
from django.db import models


class Platform(models.Model):
    name = models.CharField(max_length=64)
    acronym = models.CharField(max_length=16)


class Polygon(models.Model):
    name = models.CharField(verbose_name="Polygon Name", max_length=100)
    json_info = models.TextField(verbose_name="JSON Info")
    description = models.TextField(verbose_name="Description", null=True)
    source = models.CharField(verbose_name="Source", max_length=100, null=True)
    CVE_ENT = models.CharField(verbose_name="State Key", max_length=10, null=True)
    CVE_MUN = models.CharField(verbose_name="City Key", max_length=10, null=True)
    CVE_LOC = models.CharField(verbose_name="Location Key", max_length=10, null=True)
    CVE_AGEB = models.CharField(verbose_name="AGEB Key", max_length=10, null=True)
    E_ENT = models.CharField(verbose_name="State Stratum", max_length=10, null=True)
    E_MUN = models.CharField(verbose_name="City Stratum", max_length=10, null=True)
    E_AGEB = models.CharField(verbose_name="AGEB Stratum", max_length=10, null=True)
    wkt_polygon = models.TextField(null=True)


class Product_l1c(models.Model):
    uuid = models.CharField(max_length=50)
    identifier = models.CharField(max_length=100)
    file_path = models.CharField(max_length=150)
    json = models.TextField(null=True)


class Product_l2a(models.Model):
    prod_l1c = models.ForeignKey(Product_l1c, on_delete=models.CASCADE)
    identifier = models.CharField(max_length=100)
    file_path = models.CharField(max_length=150)


class CartProduct(models.Model):
    user = models.ForeignKey(User, on_delete=models.CASCADE)
    uuid = models.CharField(max_length=50)
    aggreg_date = models.DateTimeField(auto_now=True)  ## date of product aggregation
    info = models.TextField(null=True)
    purchased = models.NullBooleanField()


# -------------------------------------------------------------------------------------------
class Process(models.Model):
    name = models.CharField(max_length=50)
    platform = models.ForeignKey(Platform, on_delete=models.CASCADE, default='')
    productLevel = models.CharField(max_length=8, default='')


class Search(models.Model):
    area = models.TextField(null=True)
    search_name = models.TextField(default="Drawn polygon ")
    user = models.ForeignKey(User, on_delete=models.CASCADE)
    aggreg_date = models.DateTimeField(auto_now=True)  # date of product aggregation
    startDate = models.DateTimeField(verbose_name='Start Date')
    endDate = models.DateTimeField(verbose_name='End Date')
    process = models.ForeignKey(Process, on_delete=models.CASCADE, default='')  # Desbloqueo cambio de Sergio
    clouds = models.IntegerField(default=4)


class Purchase(models.Model):
    aggreg_date = models.DateTimeField(auto_now=True)  # date of product aggregation
    user = models.ForeignKey(User, on_delete=models.CASCADE)
    search = models.ForeignKey(Search, on_delete=models.CASCADE)
    productList = models.TextField(verbose_name="JSON Product List")
    purchased = models.BooleanField(default=False)
    price = models.FloatField(default=0.0)
    progress = models.IntegerField(default=0)
    is_public = models.BooleanField(default=False)

class Publics(models.Model):
    url = models.TextField()
    Purchase = models.ForeignKey(Purchase, on_delete=models.CASCADE)